import { AfterViewInit, ElementRef, EventEmitter, Injector, OnChanges, OnDestroy, OnInit, QueryList, SimpleChange } from '@angular/core';
import { AsyncValidatorFn, FormControl, FormGroup, ValidatorFn } from '@angular/forms';
import { FloatLabelType, MatError, MatFormFieldAppearance, MatSuffix } from '@angular/material';
import { Subscription } from 'rxjs';
import { OMatErrorDirective } from '../directives/o-mat-error.directive';
import { IFormDataComponent } from '../interfaces/form-data-component.interface';
import { IFormDataTypeComponent } from '../interfaces/form-data-type-component.interface';
import { PermissionsService } from '../services/permissions/permissions.service';
import { OValidatorComponent } from '../shared/components/validation/o-validator.component';
import { ErrorData } from '../types/error-data.type';
import { FormValueOptions } from '../types/form-value-options.type';
import { OInputsOptions } from '../types/o-inputs-options.type';
import { OMatErrorOptions } from '../types/o-mat-error.type';
import { OFormValue } from './form/o-form-value';
import { OFormComponent } from './form/o-form.component';
import { OFormControl } from './input/o-form-control.class';
import { OBaseComponent } from './o-component.class';
import { OValueChangeEvent } from './o-value-change-event.class';
export declare const DEFAULT_INPUTS_O_FORM_DATA_COMPONENT: string[];
export declare const DEFAULT_OUTPUTS_O_FORM_DATA_COMPONENT: string[];
export declare class OFormDataComponent extends OBaseComponent implements IFormDataComponent, IFormDataTypeComponent, OnInit, AfterViewInit, OnDestroy, OnChanges {
    sqlType: string;
    autoBinding: boolean;
    autoRegistering: boolean;
    width: string;
    clearButton: boolean;
    angularValidatorsFn: ValidatorFn[];
    angularValidatorsFnErrors: ErrorData[];
    hideRequiredMarker: boolean;
    labelVisible: boolean;
    selectAllOnClick: boolean;
    angularAsyncValidatorsFn: AsyncValidatorFn[];
    onChange: EventEmitter<object>;
    onValueChange: EventEmitter<OValueChangeEvent>;
    onFocus: EventEmitter<object>;
    onBlur: EventEmitter<object>;
    readonly hostWidth: string;
    handleClick(): void;
    protected value: OFormValue;
    protected defaultValue: any;
    protected _SQLType: number;
    protected _defaultSQLTypeKey: string;
    protected _fControl: OFormControl;
    protected _fControlSubscription: Subscription;
    protected _fGroup: FormGroup;
    protected elRef: ElementRef;
    protected form: OFormComponent;
    protected oldValue: any;
    protected _floatLabel: FloatLabelType;
    protected _appearance: MatFormFieldAppearance;
    protected matSuffixSubscription: Subscription;
    protected _matSuffixList: QueryList<MatSuffix>;
    errorsData: ErrorData[];
    protected validatorsSubscription: Subscription;
    validatorChildren: QueryList<OValidatorComponent>;
    protected permissionsService: PermissionsService;
    protected mutationObserver: MutationObserver;
    errorOptions: OMatErrorOptions;
    oMatErrorChildren: QueryList<OMatErrorDirective>;
    protected _errorChildren: QueryList<MatError>;
    protected oInputsOptions: OInputsOptions;
    constructor(form: OFormComponent, elRef: ElementRef, injector: Injector);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: {
        [propName: string]: SimpleChange;
    }): void;
    hasEnabledPermission(): boolean;
    hasVisiblePermission(): boolean;
    getFormGroup(): FormGroup;
    getFormControl(): FormControl;
    hasError(error: string): boolean;
    hasSomeError(): boolean;
    getErrorValue(error: string, prop: string): string;
    getActiveOErrors(): ErrorData[];
    initialize(): void;
    destroy(): void;
    registerFormListeners(): void;
    unregisterFormListeners(): void;
    data: any;
    setData(newValue: any): void;
    isAutomaticBinding(): boolean;
    isAutomaticRegistering(): boolean;
    getValue(): any;
    setValue(val: any, options?: FormValueOptions, setDirty?: boolean): void;
    clearValue(options?: FormValueOptions, setDirty?: boolean): void;
    onClickClearValue(event: Event): void;
    onChangeEvent(arg: any): void;
    readonly showClearButton: boolean;
    onFormControlChange(value: any): void;
    ensureOFormValue(arg: any): void;
    createFormControl(cfg?: any, validators?: ValidatorFn | ValidatorFn[], asyncValidators?: AsyncValidatorFn | AsyncValidatorFn[]): OFormControl;
    getControl(): OFormControl;
    resolveValidators(): ValidatorFn[];
    resolveAsyncValidators(): AsyncValidatorFn[];
    getSQLType(): number;
    readonly isValid: boolean;
    isEmpty(): boolean;
    setEnabled(value: boolean): void;
    readonly elementRef: ElementRef;
    readonly hasCustomWidth: boolean;
    orequired: boolean;
    innerOnFocus(event: FocusEvent): void;
    innerOnBlur(event: any): void;
    appearance: MatFormFieldAppearance;
    floatLabel: FloatLabelType;
    selectValue(): void;
    protected registerOnFormControlChange(): void;
    protected emitOnValueChange(type: any, newValue: any, oldValue: any): void;
    protected setFormValue(val: any, options?: FormValueOptions, setDirty?: boolean): void;
    protected updateOFormControlValue(value: any, options?: FormValueOptions, setDirty?: boolean): void;
    protected updateValidators(): void;
    protected addOntimizeCustomAppearanceClass(): void;
    protected getTooltipClass(): string;
    protected getTooltipText(): string;
    protected parsePermissions(): void;
    protected getMutationObserverTarget(): any;
    protected setSuffixClass(count: number): void;
    private disableFormControl;
}
